==> kpogre-1.2.7.tar.gz: kpogre-1.2.7/kpogre/DbObjects/kpgschema.h <==
//
// C++ Interface: kpgschema
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KPGSCHEMA_H
#define KPGSCHEMA_H

#include "kpgobject.h"

class KPGTablesFolder;
class KPGViewsFolder;
class KPGSequencesFolder;
class KPGFunctionsFolder;
class KPGOperatorsFolder;
class KPGOperatorClassesFolder;
class KPGAggregatesFolder;
class KPGDomainsFolder;
class KPGTypesFolder;
class KPGConversionsFolder;
class KPGSchemaPropPage;

/**
Database schema (aka namespace). A schema is essentially a namespace: it contains named objects (tables, data types, functions, and operators) whose names may duplicate those of other objects existing in other schemas. Named objects are accessed either by "qualifying" their names with the schema name as a prefix, or by setting a search path that includes the desired schema(s). Unqualified objects are created in the current schema (the one at the front of the search path, which can be determined with the function current_schema). 

@author Lumir Vanek
*/

class KPGDatabase;
class QTable;

class KPGSchema : public KPGObject
{
public:
    KPGSchema(KPGDatabase *, const QString, pqxx::oid);
		KPGSchema(KPGDatabase *, KPGSchema *, const QString, pqxx::oid);
    ~KPGSchema();
		
		virtual eNodeType type() const { return nodeSchema; }
    virtual bool isSystemObject() const { return m_bIsSystemObject; }
		void setProperties(const QString, bool, const QString, const QString);
		void setProperties(const QString, bool, const QString, const QString, pqxx::oid , const QString);
		void displayProperties(QWidget *);
		virtual bool refresh();
		bool refresh(pqxx::work &);
    bool refreshItem();
		void displayTabPage(KPGSchemaPropPage *, QWidget *);
    
    KPGTablesFolder * getTablesFolder() { return m_pFolderTables; }
    KPGViewsFolder * getViewsFolder() { return m_pFolderViews; }
    KPGSequencesFolder * getSequencesFolder() { return m_pFolderSequences; }
    KPGFunctionsFolder * getFunctionsFolder() { return m_pFolderFunctions; }
    KPGOperatorsFolder * getOperatorsFolder() { return m_pFolderOperators; }
    KPGOperatorClassesFolder * getOperatorClassesFolder() { return m_pFolderOperatorClasses; }
    KPGAggregatesFolder * getAggregatesFolder() { return m_pFolderAggregates; }
    KPGDomainsFolder * getDomainsFolder() { return m_pFolderDomains; }
    KPGTypesFolder * getTypesFolder() { return m_pFolderTypes;  }
    KPGConversionsFolder * getConversionsFolder() { return m_pFolderConversions; }
    
    const QString & owner() const { return m_strOwner; }

protected:
  void displayAggregates(QWidget *);
	void displayConversions(QWidget *);
	void displayDomains(QWidget *);
	void displayFunctions(QWidget *);
	void displayOperators(QWidget *);
	void displayOperatorClasses(QWidget *);
	void displaySequences(QWidget *);
	void displayTables(QWidget *);
	void displayTypes(QWidget *);
	void displayViews(QWidget *);
	
protected:
  KPGTablesFolder *m_pFolderTables;
  KPGViewsFolder *m_pFolderViews;
	KPGSequencesFolder *m_pFolderSequences;
  KPGFunctionsFolder *m_pFolderFunctions;
	KPGOperatorsFolder *m_pFolderOperators;
	KPGOperatorClassesFolder *m_pFolderOperatorClasses;
	KPGAggregatesFolder *m_pFolderAggregates;
	KPGDomainsFolder *m_pFolderDomains;
	KPGTypesFolder *m_pFolderTypes;	
	KPGConversionsFolder *m_pFolderConversions;
	
	bool m_bPageTablesDisplaied;
  bool m_bPageViewsDisplaied;
	bool m_bPageSequencesDisplaied;
  bool m_bPageFunctionsDisplaied;
	bool m_bPageOperatorsDisplaied;
	bool m_bPageOperatorClassesDisplaied;
	bool m_bPageAggregatesDisplaied;
	bool m_bPageDomainsDisplaied;
	bool m_bPageTypesDisplaied;	
	bool m_bPageConversionsDisplaied;
	
protected:
	// Schema properties
	QString m_strOwner;
	bool m_bCanCreate;
	QString m_strACL;
  pqxx::oid m_oidTablespace;   // For PostgreSQL 8 or newer 
  QString m_strTablespace;     // For PostgreSQL 8 or newer
  
  bool m_bIsSystemObject;
};

#endif

==> kpogre-1.5.2.tar.gz: kpogre-1.5.2/kpogre/DbObjects/kpgschema.h <==
//
// C++ Interface: kpgschema
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KPGSCHEMA_H
#define KPGSCHEMA_H

#include "kpgobject.h"

class KPGTablesFolder;
class KPGViewsFolder;
class KPGSequencesFolder;
class KPGFunctionsFolder;
class KPGOperatorsFolder;
class KPGOperatorClassesFolder;
class KPGAggregatesFolder;
class KPGDomainsFolder;
class KPGTypesFolder;
class KPGConversionsFolder;
class KPGSchemaPropPage;

/**
Database schema (aka namespace). A schema is essentially a namespace: it contains named objects (tables, data types, functions, and operators) whose names may duplicate those of other objects existing in other schemas. Named objects are accessed either by "qualifying" their names with the schema name as a prefix, or by setting a search path that includes the desired schema(s). Unqualified objects are created in the current schema (the one at the front of the search path, which can be determined with the function current_schema). 

@author Lumir Vanek
*/

class KPGDatabase;
class QTable;

class KPGSchema : public KPGObject
{
public:
    KPGSchema(KPGDatabase *, const QString, pqxx::oid);
	KPGSchema(KPGDatabase *, KPGSchema *, const QString, pqxx::oid);
    ~KPGSchema();
		
	virtual eNodeType type() const { return nodeSchema; }
	
	// Get SQL object type 
  	virtual const char * getObjectType() const { return "SCHEMA"; }
	
    virtual bool isSystemObject() const { return m_bIsSystemObject; }
	void setProperties(const QString, bool, const QString, const QString);
	//void setProperties(const QString, bool, const QString, const QString, pqxx::oid , const QString);
	void displayProperties(QWidget *);
	virtual bool refresh();
	bool refresh(pqxx::work &);
    bool refreshItem();
	void displayTabPage(KPGSchemaPropPage *, QWidget *);
    
    KPGTablesFolder * getTablesFolder() { return m_pFolderTables; }
    KPGViewsFolder * getViewsFolder() { return m_pFolderViews; }
    KPGSequencesFolder * getSequencesFolder() { return m_pFolderSequences; }
    KPGFunctionsFolder * getFunctionsFolder() { return m_pFolderFunctions; }
    KPGOperatorsFolder * getOperatorsFolder() { return m_pFolderOperators; }
    KPGOperatorClassesFolder * getOperatorClassesFolder() { return m_pFolderOperatorClasses; }
    KPGAggregatesFolder * getAggregatesFolder() { return m_pFolderAggregates; }
    KPGDomainsFolder * getDomainsFolder() { return m_pFolderDomains; }
    KPGTypesFolder * getTypesFolder() { return m_pFolderTypes;  }
    KPGConversionsFolder * getConversionsFolder() { return m_pFolderConversions; }
    
    const QString & owner() const { return m_strOwner; }
    bool isLoaded() const { return m_bIsLoaded; }
    
    void fillListOfObjectsForCodeCompletition(KPGOidNameList &);
    
protected:
  void displayAggregates(QWidget *);
	void displayConversions(QWidget *);
	void displayDomains(QWidget *);
	void displayFunctions(QWidget *);
	void displayOperators(QWidget *);
	void displayOperatorClasses(QWidget *);
	void displaySequences(QWidget *);
	void displayTables(QWidget *);
	void displayTypes(QWidget *);
	void displayViews(QWidget *);
	
  virtual void activate();
    
protected:
  KPGTablesFolder *m_pFolderTables;
  KPGViewsFolder *m_pFolderViews;
	KPGSequencesFolder *m_pFolderSequences;
  KPGFunctionsFolder *m_pFolderFunctions;
	KPGOperatorsFolder *m_pFolderOperators;
	KPGOperatorClassesFolder *m_pFolderOperatorClasses;
	KPGAggregatesFolder *m_pFolderAggregates;
	KPGDomainsFolder *m_pFolderDomains;
	KPGTypesFolder *m_pFolderTypes;	
	KPGConversionsFolder *m_pFolderConversions;
	
	bool m_bPageTablesDisplaied;
  bool m_bPageViewsDisplaied;
	bool m_bPageSequencesDisplaied;
  bool m_bPageFunctionsDisplaied;
	bool m_bPageOperatorsDisplaied;
	bool m_bPageOperatorClassesDisplaied;
	bool m_bPageAggregatesDisplaied;
	bool m_bPageDomainsDisplaied;
	bool m_bPageTypesDisplaied;	
	bool m_bPageConversionsDisplaied;
	
protected:
	// Schema properties
	QString m_strOwner;
	bool m_bCanCreate;
	QString m_strACL;
  
  // Note: Information about tablespace was removed from schema between PostgreSQL 8 b4 and 8.0 final
  //pqxx::oid m_oidTablespace;   // For PostgreSQL 8 or newer 
  //QString m_strTablespace;     // For PostgreSQL 8 or newer
  
  bool m_bIsSystemObject;
  bool m_bIsLoaded;
};

#endif
